@@ -32,7 +32,7 @@ describe 'openstacklib::openstackclient' do
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :openstackclient_package_name => 'python3-openstackclient' }
         when 'RedHat'
