@@ -27,13 +27,13 @@ describe 'openstacklib::policy::base' do
         :purge_config => false,
       )}
 
-      it { should contain_augeas('/etc/nova/policy.json-context_is_admin or owner-foo:bar').with(
+      it { should contain_augeas('/etc/nova/policy.json-context_is_admin or owner').with(
         :lens    => 'Json.lns',
         :incl    => '/etc/nova/policy.json',
         :changes => 'set dict/entry[*][.="context_is_admin or owner"]/string "foo:bar"',
       )}
 
-      it { should contain_augeas('/etc/nova/policy.json-context_is_admin or owner-foo:bar-add').with(
+      it { should contain_augeas('/etc/nova/policy.json-context_is_admin or owner-add').with(
         :lens    => 'Json.lns',
         :incl    => '/etc/nova/policy.json',
         :changes => [
@@ -72,7 +72,7 @@ describe 'openstacklib::policy::base' do
       it { should contain_file_line('/etc/nova/policy.yaml-context_is_admin or owner').with(
         :path  => '/etc/nova/policy.yaml',
         :line  => '\'context_is_admin or owner\': \'foo:bar\'',
-        :match => '^[\'"]?context_is_admin or owner[\'"]?\s*:.+'
+        :match => '^[\'"]?context_is_admin or owner(?!:)[\'"]?\s*:.+'
       ) }
 
       context 'with single-quotes in value' do
@@ -85,7 +85,7 @@ describe 'openstacklib::policy::base' do
         it { should contain_file_line('/etc/nova/policy.yaml-context_is_admin or owner').with(
           :path  => '/etc/nova/policy.yaml',
           :line  => '\'context_is_admin or owner\': \'foo:\'\'bar\'\'\'',
-          :match => '^[\'"]?context_is_admin or owner[\'"]?\s*:.+'
+          :match => '^[\'"]?context_is_admin or owner(?!:)[\'"]?\s*:.+'
         ) }
       end
 
@@ -99,7 +99,7 @@ describe 'openstacklib::policy::base' do
         it { should contain_file_line('/etc/nova/policy.yaml-context_is_admin or owner').with(
           :path  => '/etc/nova/policy.yaml',
           :line  => '\'context_is_admin or owner\': \'foo:\'\'bar\'\'\'',
-          :match => '^[\'"]?context_is_admin or owner[\'"]?\s*:.+'
+          :match => '^[\'"]?context_is_admin or owner(?!:)[\'"]?\s*:.+'
         ) }
       end
     end
